/*
 * @(#)PopSshExample.java
 *
 * Copyright (c) JSCAPE LLC.
 * 1147 S. 53rd Pl., Mesa, Arizona, 85206, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * JSCAPE. ("Confidential Information").  You shall not disclose such
 * Confidential Information and shall use it only in accordance with
 * the terms of the license agreement you entered into with JSCAPE.
 */

import com.jscape.inet.pop.*;
import com.jscape.inet.popssh.*;
import com.jscape.inet.ssh.util.*;
import com.jscape.inet.email.*;
import com.jscape.inet.mime.*;
import java.util.Enumeration;
import java.io.*;

public class PopSshExample extends PopAdapter {

	static BufferedReader reader =
		new BufferedReader(new InputStreamReader(System.in));
	SshParameters sshParams;

	public PopSshExample(SshParameters sshParams) {
		this.sshParams = sshParams;
	}

	// get messages from Pop mailbox
	public void getMessages(String hostname, String username, String password)
		throws PopException, MimeException, IOException {
		PopSsh pop = new PopSsh(sshParams, hostname, username, password);
		
		// register listener to capture events 
		pop.addPopListener(this);
		
		// establish connection to POP3 server via SSH tunnel
		pop.connect();
		
		
		System.out.println("Retrieving messages...");

		// get message count
		int messageCount = pop.getMessageCount();
		System.out.println(messageCount + " messages found.  Please wait...");

		// get all messages			
		if (messageCount < 1) {
			System.out.println("No messages found");
		}
		
		// loop thru messages retrieved
		for(int i = 1; i <= messageCount; ++i) {
			System.out.println("-- begin message --");
			EmailMessage msg = (EmailMessage) pop.getMessage(i);
			System.out.println(new String(msg.getMessage()));
			System.out.println("-- end message --");

			System.out.print("ENTER for next message or type QUIT to quit: ");
			String command = reader.readLine();
			if (command.equalsIgnoreCase("quit")) {
				break;
			}
		}
		pop.disconnect();
	}


	/**
	 * Overloads messageRetrieved method in PopAdapter
	 */
	public void messageRetrieved(PopMessageEvent event) {
		System.out.println("Retreived message " + event.getMessage());
	}

	public static void main(String[] args) {
		String hostname;
		String username;
		String password;
		String sshHostname;
		String sshUsername;
		String sshPassword;

		try {
			System.out.print("Enter SSH hostname (e.g. ssh.myserver.com): ");
			sshHostname = reader.readLine();

			System.out.print("Enter SSH username (e.g. jsmith): ");
			sshUsername = reader.readLine();

			System.out.print("Enter SSH password (e.g. secret): ");
			sshPassword = reader.readLine();

			// create SSH connection parameters
			SshParameters sshParams =
				new SshParameters(sshHostname, sshUsername, sshPassword);

			System.out.print("Enter Pop3 hostname (e.g. mail.domain.com): ");
			hostname = reader.readLine();
			System.out.print("Enter Pop3 Username: ");
			username = reader.readLine();
			System.out.print("Enter Pop3 Password: ");
			password = reader.readLine();
			PopSshExample example = new PopSshExample(sshParams);
			example.getMessages(hostname, username, password);
		} catch (Exception e) {
			e.printStackTrace();
		}
	}
}
