/*
 * @(#)SmtpAttachmentExample.java
 *
 * Copyright (c) JSCAPE LLC.
 *
 * This software is the confidential and proprietary information of
 * JSCAPE. ("Confidential Information").  You shall not disclose such
 * Confidential Information and shall use it only in accordance with
 * the terms of the license agreement you entered into with JSCAPE.
 */

import com.jscape.inet.smtp.*;
import com.jscape.inet.mime.*;
import com.jscape.inet.email.*;
import java.io.*;

public class SmtpAttachmentExample extends SmtpAdapter {
    public void sendMessage(String hostname, String to, String from, String subject, String body, String attachment) throws SmtpException, 
    IOException, MimeException {
    	
    	// create new Smtp instance
        Smtp smtp = new Smtp(hostname);
        
        // enable debugging ... all output is sent to System.out
        smtp.setDebug(true);
        
        // capture SMTP related events
        smtp.addSmtpListener(this);
        
        // connect to mail server
        smtp.connect();
        
        // create new email message
        EmailMessage email = new EmailMessage();
        
        // set recipient address
        email.setTo(to);
        
        // set from address
        email.setFrom(from);
        
        // set subject
        email.setSubject(subject);
        
        // set body
        email.setBody(body);
        
        // add file attachment to message
        email.addAttachment(new Attachment(new File(attachment)));
        
        // send email message
        smtp.send(email);
        
        // disconnect from SMTP server
        smtp.disconnect();
    }
    
    // capture connect event
    public void connected(SmtpConnectedEvent evt) {
        System.out.println("Connected to Smtp server: " + evt.getHostname());
    }
    
    // capture disconnect event
    public void disconnected(SmtpDisconnectedEvent evt) {
        System.out.println("Disconnected from Smtp server: " + evt.getHostname());
    }
    
    public static void main(String[] args) {
        String hostname;
        String to;
        String from;
        String subject;
        String body;
        String attach;
        try {
            BufferedReader reader = new BufferedReader(new InputStreamReader(System.in));
            System.out.print("Enter Smtp hostname (e.g. mail.domain.com): ");
            hostname = reader.readLine();
            System.out.print("Enter To address (e.g. recipient@domain.com): ");
            to = reader.readLine();
            System.out.print("Enter From address (e.g. sender@domain.com): ");
            from = reader.readLine();
            subject = "iNet Factory Attachment Example";
            body = "see attached image";
            attach = "image.gif";
            SmtpAttachmentExample example = new SmtpAttachmentExample();
            example.sendMessage(hostname,to,from,subject,body,attach);
        }
        catch(Exception e) {
            e.printStackTrace();
        }
    }
}

